library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
use work.router_pkg.all;

entity router is
	generic(
		N           : integer;
		BUFFER_SIZE : integer
	);
	port(
		in_clk      : std_logic;
		in_reset    : std_logic;
		in_port_p1  : in  router_port_p1_t;
		in_port_p2  : out router_port_p2_t;
		out_port_p1 : out router_port_p1_array_t(0 to 2 ** N - 1);
		out_port_p2 : in  router_port_p2_array_t(0 to 2 ** N - 1)
	);
end entity router;

architecture RTL of router is
	signal fifo_port_p1 : router_port_p1_array_t(0 to 2 ** N - 1);
	signal fifo_port_p2 : router_port_p2_array_t(0 to 2 ** N - 1);
	signal port_p2      : router_port_p2_t;
begin
	fifos : for i in fifo_port_p1'range generate
	begin
		fifo_inst : entity work.fifo
			generic map(
				N => BUFFER_SIZE
			)
			port map(
				in_clk             => in_clk,
				in_reset           => in_reset,
				in_router_port_p1  => fifo_port_p1(i),
				in_router_port_p2  => fifo_port_p2(i),
				out_router_port_p1 => out_port_p1(i),
				out_router_port_p2 => out_port_p2(i)
			);
	end generate;

	comb : process(in_port_p1, fifo_port_p2) is
		variable write : std_logic;
	begin
		for i in fifo_port_p1'range loop
			fifo_port_p1(i) <= in_port_p1;
			if (std_logic_vector(to_unsigned(i, N)) /= in_port_p1.address(N - 1 downto 0)) then
				fifo_port_p1(i).write <= '0';
			end if;
		end loop;

		write := '0';
		for i in fifo_port_p2'range loop
			write := write or fifo_port_p2(i).ack;
		end loop;
		port_p2.ack <= write;
	end process comb;

	in_port_p2 <= port_p2;
end architecture RTL;
