library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

use std.textio.all;

use work.CoveragePkg.all;
use work.RandomPkg.all;
use work.router_pkg.all;

package test_pkg is
	type test_send_package_in_t is record
		address     : router_address_t;
		data        : router_data_t;
		wait_period : integer;
	end record;

	type test_send_package_out_t is record
		ack : std_logic;
	end record;

	type test_recv_package_out_t is record
		address : router_address_t;
		data    : router_data_t;
		ack     : std_logic;
	end record;

	type test_recv_package_out_array_t is array (natural range <>) of test_recv_package_out_t;

	type test_recv_package_in_t is record
		wait_period : integer;
		ack         : std_logic;
	end record;

	type test_recv_package_in_array_t is array (natural range <>) of test_recv_package_in_t;

	type test_list_data_t is record
		address : router_address_t;
		data    : router_data_t;
		time    : integer;
		marked  : boolean;
	end record;

	type test_list_data_p is access test_list_data_t;

	type test_list_elem_t;
	type test_list_elem_p is access test_list_elem_t;
	type test_list_elem_t is record
		data   : test_list_data_t;
		next_p : test_list_elem_p;
	end record;

	type test_list_package_t is protected
		procedure init;
		procedure add(e : test_list_data_t);
		impure function mark(e : test_list_data_t) return boolean;
		impure function all_marked return boolean;
		procedure deallocate;
		procedure iter_start;
		impure function iter_end return boolean;
		procedure iter_next;
		impure function iter_curr return test_list_data_t;
	end protected test_list_package_t;

	procedure write(file f : text; variable list : inout test_list_package_t; header : string);

	type test_port_list_t is protected
		procedure init;
		impure function add(i : integer) return integer;
		procedure sub(i : integer);
		impure function value(i : integer) return boolean;
		impure function empty return boolean;
		procedure deallocate;
	end protected test_port_list_t;

	function build_in_data(data : integer; address : integer; port_n : integer; port_s : integer; wait_t : integer) return test_send_package_in_t;

	function to_test_list_data(e : test_send_package_in_t) return test_list_data_t;
		
	function to_test_list_data(address : router_address_t; data : router_data_t; wait_c : integer) return test_list_data_t;
		
end package test_pkg;

library ieee;
use ieee.numeric_std.all;
library ieee;
use ieee.numeric_std.all;
package body test_pkg is
		`protect BEGIN_PROTECTED
`protect version = 1
`protect encrypt_agent = "Model Technology", encrypt_agent_info = "10.1e"
`protect key_keyowner = "Mentor Graphics Corporation" , key_keyname = "MGC-VERIF-SIM-RSA-1" , key_method = "rsa"
`protect encoding = (enctype = "base64", line_length = 64, bytes = 128)
`protect KEY_BLOCK
m97Flvc+/sC8JSF9z9NobNriSIXnL09KJ9vT9y7InS4LLbHzdE5a5Il/pgSfEQZL
sTVaQm7gKT1EHty/tMwxu/3R7FU8WXle61+FgqvIdw5FXTAhjd0AWl5ZSXYIbpeA
tBQmh6v3GSx/L1BqJm66GMgG253Sspff6Dsgq7JnTBo=
`protect data_method = "aes128-cbc"
`protect encoding = (enctype = "base64", line_length = 64, bytes = 5622)

`protect DATA_BLOCK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`protect END_PROTECTED
end package body test_pkg;
