library ieee;
use ieee.std_logic_1164.all;

use std.textio.all;

use work.CoveragePkg.all;
use work.RandomPkg.all;
use work.test_pkg.all;
use work.router_pkg.all;

entity test_router_p is
	generic(
		N_OUTPUT    : integer;
		BUFFER_SIZE : integer;
		log_file    : string := "log.txt";
		safe_wait   : time   := 1 ms
	);
	port(
		in_clk      : in  std_logic;
		in_reset    : in  std_logic;
		out_data    : out test_send_package_in_t;
		ack_data    : in  test_send_package_out_t;

		in_data_in  : in  test_recv_package_out_array_t(0 to 2 ** N_OUTPUT - 1);
		in_data_out : out test_recv_package_in_array_t(0 to 2 ** N_OUTPUT - 1);

		out_stop    : out std_logic;
		out_start   : out std_logic
	);
end entity test_router_p;

architecture RTL of test_router_p is 
		`protect BEGIN_PROTECTED
`protect version = 1
`protect encrypt_agent = "Model Technology", encrypt_agent_info = "10.1e"
`protect key_keyowner = "Mentor Graphics Corporation" , key_keyname = "MGC-VERIF-SIM-RSA-1" , key_method = "rsa"
`protect encoding = (enctype = "base64", line_length = 64, bytes = 128)
`protect KEY_BLOCK
FwQCyHSFUahmGFge72RkYQt2h89nZbY0sWoI59PmmGx7Wdy0Sqns8PUe8nmoRzmi
GG1HMPVuNTBe9QKQX/aIpZR0ZslDIcZlNSyAsNtw1GhY/gygVbdwc7GxA3KIZG8T
y8UxMNpbFE9m0Ri1wrdHon7iL5nx8Rq7Ixrwth9mIWA=
`protect data_method = "aes128-cbc"
`protect encoding = (enctype = "base64", line_length = 64, bytes = 4147)

`protect DATA_BLOCK
M+Bo5kgM73OAAbEI2C+FwkrsY03symc+m5vP6rjpHXfRH3eKiuHEeXzeP6of/0Dk
uZnnc736nht/6ELc6tAvk+yRwHr+RyJmcOvbwbR68UIYpFFa18E26438hutxZagi
/OhyjmJXFAkGMYWz71ox58va7SlxtxzUJFTK0X0b7JvGV2lEgT4th1Ch5VvP6NOs
RY0prlUSemdu7O/ZcMkIyUC+fuVsSUn+y7yeOVMkRfIdCcJcdEQgs9CzxPJZnYmS
JNP5HmacCj4m7xsCZ7AUfpFNsLQ0FiRtY56xxVq9CwV3OhGpszRUSdhKDdyMpvPn
SAF9wBm5AjDPAsoAqTmHRTbIoNctNXCtEEsM6U9W2PtJqo4Yxl/8VcvnqMOuctUP
3r9/DqqpZEOh7EQCw2FVTVJ45Mke+oYmU7PBHs8RtiqCAAy+3FBlT46yh2ahv6ZN
53lhG3QqPGxBd41jNvuMz46CHt6eVTcwWGmKVLGxPN1SdJ8izrDh1iAFlhKxhBQU
R5ASZ34HLumavuqgomrrxAWZAykzpFeJvD9kJWDnaAhkQl3BMvBGt2sJPWDbXBRM
Z1xKvLUJZzaZVyqEaxjfb7Pm/JEdVC9/qct1glcsdkzeEfg8YElmHFky38u5bV3w
wNhauR2vdjHyYXNST/Clnux8G3KaxlA5Crnr4WJ23pFj8LJRg5MUbudJbNzev2/4
klCw5NbXC10YIcXBhAQcm52dSJKuyGDz74XWDRRyp38haN4vCndTB7vKjZDSOO/x
PCM9U2Ow3LOjGJIZv99FI74/1ooMG5k06gVOJiSgr6mzjKmflItCrOOEakB8ndSz
kjAPlaKCglpVtuMyrIx5IGrR8b1boXuG1SwL9N7dvaacbK3Z+C5SPuQXLgCNTWr3
2DG3Zfw1/wgopSiZ6S9JILXTJTjqyrieJcJrXtATlUPhTx8TEIr2fcn2BIGnK2dp
ggIZdKLHFvOvlmv4wEr9ryDdn3A6CHmqtE8aSdabO7oaC+/668BoPVuUn6FYSsxk
PIPxJpXsuPCIkBnHhu1B+CA81nsG9Fs+VIFOjiIKbv5h1AD0H/nlXijBKz+8HfpG
6T388t92ZGg25RJZjoHGGk+PMpmSFxkeUHWpOr0I7gbt1S8wkRtLSZpw37rdV1+s
fYmKibic0Y7MnLgp05/z1/aqYgWk7KYDADRatONM+o3HnJ/M7bY3T4Ocg6BQOTLv
agbbKXtU6kmlNpPeDKa2LFP7x+L4/XYpvsXXjAdQG44LgHRoc5tTjiAkWXX6BfrJ
6MOgyxGSAliG/hTKD7L18J6rSyLv434EP9Gvbz07CP5risSAu/9iWyYWP5jRnlMf
jgyV5Gh92jK5C7QbzYYhpGnf8nKG94L7k+qNuZwblTwUUvspo1b+xeGt2vhC6tMM
NaRRDI8ZkXV3Bytj9v2QKSreFw2C6kmea66TUkAM7sUHm5f0VEwLfUb1Au/moVcO
F4NjyI5PaCEffnyccSO4mpok2bBsBbtTNZvOQQWMzOQx5dnqzmg6eOWl3CzmGHcL
jrtTR5rohz2egsIXOmZby8VGEmR0vJbv+kFKZ+Puv6/NMZ3uxkhXm3VD9LnHjDIE
wUjKcd4seAOofmdVMi/Hgi2kvU6NFSg1Gldpd992rPDpg/awvWjS0VZYpwRVK5vC
sC9TO6IRNFHiZK3Obh1JsE8oBs0GGnmwkacwgQkGMgdQ3RcCqaXruav9F8NCkXjG
L+bzYzrpUGZORiZzBvyLbrMERwqHvQDc5ttqabndlos9lpQXQj3WuqD796dPgNBN
lw9IRQumgh6C1Js2uIHfaxEsnsTJIQN6WnQpiV7K7yhboSm1ALzNxz1pOrarMGvP
8RZzV/RGXj+JPV8+Pd7njFxbwm13Rj0Xt9IX/KkdGqax97utxAU8uX6A2gUiC0Dx
w5PQhg2X2Z9hqdTS4Y69lb2dmwFIO3rx5XTBot7ZSO6OGxwz8yRr77brWmtjlZJn
zFfQ6mPb4KYQ3CNvii9pdVG0U9RmCFbUj9v5eW7b0qdqiN23bq5YJ9bBT/HgWbZr
rNN3eRdJYs4MJWOUoIXjxEOmkzJEA6V9c734Yw1YxRrGj4b6P4H42QuPmIbOEwjZ
HCOYRZLi7A4H1rbgBC8qHM4yK38cJUSTDyTn6QyynqDjItgpRoNYWUfOXuOLq2uQ
oxvtVkwQp6cPXEBsBxtaciNvwY5zRoWy9+wz0zcs1BPLAb7FOJ107FAxt/aqR+uI
El0Isciq5Fnei4fsGMKumEdVl4sH4hzpYOR5PyGYlgIDZYwKd8OerdToht5Wc45i
thMPfRqR7oKIKy7DYk1A3Ig7coAtUXtCFrm9Ii/3JIJSf5KNFQ054sA0ifGZ37Uc
QFpE7clyotrneoVZoHt4DKVyEpbE6COUH1TV7LMnY/xBFgXM7B+cGQBe7J3qooan
rifGED6wUBsV88Jy/jM5OM06V12+w0qIIqTYItddbxolLK+/A7XiK2PsiysmhzCR
HorSmR4K0QRfDA4G3YzS430QQln17lE0ez4avv0RwvcmkyN2uZX+qjCMKrHnJVBd
4v+FlJ9ZhZrxeEMA1iq3Q+AJV6Ygix8vmFMJ40277mpn4L0IxUc+oG+ArOBiEpT+
ebNNfPeYCFYgv0znk8mQ6imxKfwXLgbHQp7lr3MCsWHysFT5dFisJLJMs7J+XQW1
uI9CacudECfdS9z/0CwDM2GSJCA23RJmbCW+AqgGAzBNWdaUK9WfP7AD89x52Pf4
HYZ/HpyuhOyRK9P6wGdgwDdPg9FJvjbMDcm8bs/GL4dNmCDn1UcjeFXxKAZ9cD5N
ITW5ITToCbzGV8BCMo5y2fS+ZomWVQ4haaaYGJw5hD+Yw50SVOjNt2MZH/IHCTuG
ttAs6o8ZOebwFw+sSoqJQlIj+INSWbmMtK/uaHnDxHrc7fR9V+vkJpnB4MKE4R8k
CRpAlDqemE4D4FxH3GaKJuiAYF+ULBeKrJHpZJI02VZeaMMc8S/fGqqW8Y5Lb/HY
PnP30JtgF0swxvAOv3BwvayLbHP/rxwY/ZtFaGejDhGckTSaN5q0fx/RI3SETC1Q
/A7Tf9btqTRyJnuPjHRopRmOH6/c8uXpOiP+3pCmVvuDQRKNcyaIhTIpXSgKUImk
qCTPJ/HSvrhxLgt6cQKpfnbTReFgcAdgYV7MAD5BXGxQ+k3t3+927XPC156ko++1
dqd2YdzAuZO1OJ2GWAuem8tpRhYKsuNeEXEKuN36EvWKKfGFEkmt/l3X0/tQqyk9
an0jJsl8vMtsC/YgYNz4FMN+OiBds+85XzbSOvZjGhpJrdZdh2dUDqKssA5TfQjS
EXmekGEaHBgZ7uvZkC/y86gLGpRo64u4MLEP9Vo+7QGMoTlwlSO2ouKEPd16Ira/
PbYsecF+Ixul98Hs6Ya3m3iRJozbiRcQBevA+0GTIceGpL/ZtHQliAmzUSQ0ehiY
V8rNNoDe16HitqumfzZZ0fZdUZ+UCctJ3CIOB3xd/r0NAEQOLKuauO9WDDIzGgtc
n7TRtov5YAgjvXp6+rlfWaYkCRBd6Me6DsDq2OnrHGxrWyYfjtErGBfZWI3WGRUH
82dxcABrg5GV0cY0aIyyo6o6hlegcLXkIrFJrtH9dyv5fMLQ5qbRhRsjkebsFapI
6MscFXvLq4+DFzLdWD+8Z/EW8+25TXimunEbnk5KQk0sE4+CXt0bocsoVhAmEotV
89ZJ5ZPJETTfyjj4But3PfBfUTGsM6/GWfN9VBEhSHJr6KPYTIXjGeaqnwkuZyM3
hTROwoinvxi9kXaDclJBvdPbF6qZvn4S02PYYpg3CI6GQQ2fbDcz0liue4OSiqTT
s8lCibWTBWk9wOHht/butJZ5Yka2HftnFNBsmYPtMLHpV3Uv3oQg5onHESraxhvv
NcYrfz/jv/fYxBl/Z13AO19yjart3OclgTO0WHJqCgglXH4D0RcFs6RohxGWur4w
ZaOBCOwNEukaIuW5qKEVthpf8DZk23Vvqn9rSyCHf8wSnVp1u6nBkghaGJIQN8vD
3qP8slp1tHFP9BHEkdd9OE6rmZ25UGDnaTPSV/v64FBOaK8E2Wc9GnQK3MJvOxB4
P7GMx7R5/svAeDEGzzOg2UKEcWbRtUw2XLTQVmKL+Ea3qivwDXnRInEeQ3lQsLrn
APzhm94aSkBiHmcNgKEw77N+8mQAx8ZkQ8djpEdYX8C+nAAZ2mZugyIYsFIBW5Bc
pWRwQ1/RB05FDjp/PhWJ/KT3e/jVKMUWvkCJfd9M3MyPSe/pbTBkTXWOaI21q6Bw
cb71ucruYuLJV9UI0qFuuJxnq+q8AmkRcw+jymxB78uGdGZPMzgB3D3YUoIbXBmJ
GSA/8DFOu1F8pBkhPckxCLI+4ljsZP2OOzFYO3DL0Bx4ao3Bh0wQVmf1Fx7agVze
qhrH3LK89SfnqGzrgBlzWuf2ap57C9NMNXTuplNWpaHDfsRVA1XTvOIXK/53EkUM
g7txoJ2cxJA1lWW/hvMCaVf3lGkRi2W+efZzZRTkW4PEE/YExktXKLbHOE1njWvI
lC0vw8y6I/e/10qoX6dHL+KLNOHSfYZ1HuJ/P2hB1XDiAIabFCAr4Hy9fwENKnnO
AnDi0aGUBtPySQgQDXlJUXoweNhDMidYBeFsWw7Zzh5OdZNn30DWFS0H1ERXARmV
M2dCLwywV+hQ/adLrdjgDdYFgC27Xih2uvD+bJDMb3TSlj8uDYpeyecbUaZjvJsd
TjswmfIaTCdvZOjKrn5tBGkmXwhVpU14cALOQxHU2/buqToHgQxBCVYsG8vFgYm6
/a5lg6i8XPExoFS304sVkxJ6yl4FIzJONvesOtwxRuA9C0OdHfKhAsD66JvSL2B2
9G01zLwkdH8IqibZ4IY0feDmwrAZOprcEoeQNwlIURGwMXym5moxpuFB6FM2SoNR
AyxKLhsgByWga0teUqpRf3lH8w8ygiE4boHkAV91R8Wlcn+Y0k7rMhqVaJTqrtWe
NXvwvy58aMXv2YNTw8CRtOUboyWKyjlGKPO1xK2a+sAHwTaQSSGMGS5/mi4py6yB
GyK21E3Tx4sy7b2k+T/iYndejCv6sKVVrhJEkAVvHlp5yPYmSo1squytsxP1VrIy
P/splrKqMgEXi76RfTJx69u8O7sGhTIqWg4I1xKhil0/jtrL7KORex6BVkNaUFp5
s/pJ1AT8V77uAKSS7q1mPFBRPWMJCl3bLzPL8COeQ4MNX6uPpKg2VYG9G23tSxDh
Ffw/uKtfNWqbZ+x3pq9c+uLbnClwluqOKEjOjcrokg1gLqTxgpU0Uhs8OzXpqcvj
5bU+B9DQj3sKirJbcrY+GfrEk2DfAOHvemJQT1TdhGpL+6nmCwSmr0edLrnp8Pq2
fRoQVETr/8qEu/edJ73Lew5t62GF3C4sBqDpMKIvCITVl3A/4BD9q3FT1H8hSRDJ
lF2Tq9c+BK28G4NxeNSgIQYCUwt5bk7eVia3LbS+GRPJ/oKQtpfUyPVsBeyxdcqb
Ukzh8djvCYZZbUFzBq51BD0L05eNo+kF1xMqH19YMeTcCBZKTXrDWxYv/h3e9Iko
`protect END_PROTECTED
end

	architecture RTL ;
